==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/nonconformity_001/EquipmentDetails.java <==

package net.datastream.schemas.mp_entities.nonconformity_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CATEGORYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.CRITICALITYID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import net.datastream.schemas.mp_fields.UCODEID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}OPERATIONALSTATUS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCLASSID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SAFETY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CRITICALITYID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MODEL" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSTATUS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LINEARDIRECTIONID" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "type",
    "departmentid",
    "operationalstatus",
    "equipmentclassid",
    "categoryid",
    "safety",
    "criticalityid",
    "assignedto",
    "manufacturerid",
    "model",
    "equipmentstatus",
    "lineardirectionid"
})
@XmlRootElement(name = "EquipmentDetails")
public class EquipmentDetails {

    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type type;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "OPERATIONALSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type operationalstatus;
    @XmlElement(name = "EQUIPMENTCLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type equipmentclassid;
    @XmlElement(name = "CATEGORYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CATEGORYID categoryid;
    @XmlElement(name = "SAFETY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String safety;
    @XmlElement(name = "CRITICALITYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CRITICALITYID_Type criticalityid;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "MANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MANUFACTURERID_Type manufacturerid;
    @XmlElement(name = "MODEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String model;
    @XmlElement(name = "EQUIPMENTSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type equipmentstatus;
    @XmlElement(name = "LINEARDIRECTIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UCODEID_Type lineardirectionid;

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the operationalstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getOPERATIONALSTATUS() {
        return operationalstatus;
    }

    /**
     * Sets the value of the operationalstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setOPERATIONALSTATUS(STATUS_Type value) {
        this.operationalstatus = value;
    }

    /**
     * Gets the value of the equipmentclassid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getEQUIPMENTCLASSID() {
        return equipmentclassid;
    }

    /**
     * Sets the value of the equipmentclassid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setEQUIPMENTCLASSID(CLASSID_Type value) {
        this.equipmentclassid = value;
    }

    /**
     * Gets the value of the categoryid property.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Sets the value of the categoryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Gets the value of the safety property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSAFETY() {
        return safety;
    }

    /**
     * Sets the value of the safety property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSAFETY(String value) {
        this.safety = value;
    }

    /**
     * Gets the value of the criticalityid property.
     * 
     * @return
     *     possible object is
     *     {@link CRITICALITYID_Type }
     *     
     */
    public CRITICALITYID_Type getCRITICALITYID() {
        return criticalityid;
    }

    /**
     * Sets the value of the criticalityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CRITICALITYID_Type }
     *     
     */
    public void setCRITICALITYID(CRITICALITYID_Type value) {
        this.criticalityid = value;
    }

    /**
     * Gets the value of the assignedto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Sets the value of the assignedto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Gets the value of the manufacturerid property.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getMANUFACTURERID() {
        return manufacturerid;
    }

    /**
     * Sets the value of the manufacturerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setMANUFACTURERID(MANUFACTURERID_Type value) {
        this.manufacturerid = value;
    }

    /**
     * Gets the value of the model property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMODEL() {
        return model;
    }

    /**
     * Sets the value of the model property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMODEL(String value) {
        this.model = value;
    }

    /**
     * Gets the value of the equipmentstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTSTATUS() {
        return equipmentstatus;
    }

    /**
     * Sets the value of the equipmentstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTSTATUS(STATUS_Type value) {
        this.equipmentstatus = value;
    }

    /**
     * Gets the value of the lineardirectionid property.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getLINEARDIRECTIONID() {
        return lineardirectionid;
    }

    /**
     * Sets the value of the lineardirectionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setLINEARDIRECTIONID(UCODEID_Type value) {
        this.lineardirectionid = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_entities/nonconformity_001/EquipmentDetails.java <==

package net.datastream.schemas.mp_entities.nonconformity_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CATEGORYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.CRITICALITYID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.TYPE_Type;
import net.datastream.schemas.mp_fields.UCODEID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TYPE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OPERATIONALSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTCLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CATEGORYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SAFETY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CRITICALITYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSIGNEDTO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MODEL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSTATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINEARDIRECTIONID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "type",
    "departmentid",
    "operationalstatus",
    "equipmentclassid",
    "categoryid",
    "safety",
    "criticalityid",
    "assignedto",
    "manufacturerid",
    "model",
    "equipmentstatus",
    "lineardirectionid"
})
@XmlRootElement(name = "EquipmentDetails")
public class EquipmentDetails {

    @XmlElement(name = "TYPE", namespace = "http://schemas.datastream.net/MP_fields")
    protected TYPE_Type type;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "OPERATIONALSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type operationalstatus;
    @XmlElement(name = "EQUIPMENTCLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type equipmentclassid;
    @XmlElement(name = "CATEGORYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CATEGORYID categoryid;
    @XmlElement(name = "SAFETY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String safety;
    @XmlElement(name = "CRITICALITYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CRITICALITYID_Type criticalityid;
    @XmlElement(name = "ASSIGNEDTO", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type assignedto;
    @XmlElement(name = "MANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected MANUFACTURERID_Type manufacturerid;
    @XmlElement(name = "MODEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected String model;
    @XmlElement(name = "EQUIPMENTSTATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type equipmentstatus;
    @XmlElement(name = "LINEARDIRECTIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected UCODEID_Type lineardirectionid;

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getTYPE() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setTYPE(TYPE_Type value) {
        this.type = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the operationalstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getOPERATIONALSTATUS() {
        return operationalstatus;
    }

    /**
     * Sets the value of the operationalstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setOPERATIONALSTATUS(STATUS_Type value) {
        this.operationalstatus = value;
    }

    /**
     * Gets the value of the equipmentclassid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getEQUIPMENTCLASSID() {
        return equipmentclassid;
    }

    /**
     * Sets the value of the equipmentclassid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setEQUIPMENTCLASSID(CLASSID_Type value) {
        this.equipmentclassid = value;
    }

    /**
     * Gets the value of the categoryid property.
     * 
     * @return
     *     possible object is
     *     {@link CATEGORYID }
     *     
     */
    public CATEGORYID getCATEGORYID() {
        return categoryid;
    }

    /**
     * Sets the value of the categoryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CATEGORYID }
     *     
     */
    public void setCATEGORYID(CATEGORYID value) {
        this.categoryid = value;
    }

    /**
     * Gets the value of the safety property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSAFETY() {
        return safety;
    }

    /**
     * Sets the value of the safety property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSAFETY(String value) {
        this.safety = value;
    }

    /**
     * Gets the value of the criticalityid property.
     * 
     * @return
     *     possible object is
     *     {@link CRITICALITYID_Type }
     *     
     */
    public CRITICALITYID_Type getCRITICALITYID() {
        return criticalityid;
    }

    /**
     * Sets the value of the criticalityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CRITICALITYID_Type }
     *     
     */
    public void setCRITICALITYID(CRITICALITYID_Type value) {
        this.criticalityid = value;
    }

    /**
     * Gets the value of the assignedto property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getASSIGNEDTO() {
        return assignedto;
    }

    /**
     * Sets the value of the assignedto property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setASSIGNEDTO(PERSONID_Type value) {
        this.assignedto = value;
    }

    /**
     * Gets the value of the manufacturerid property.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getMANUFACTURERID() {
        return manufacturerid;
    }

    /**
     * Sets the value of the manufacturerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setMANUFACTURERID(MANUFACTURERID_Type value) {
        this.manufacturerid = value;
    }

    /**
     * Gets the value of the model property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMODEL() {
        return model;
    }

    /**
     * Sets the value of the model property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMODEL(String value) {
        this.model = value;
    }

    /**
     * Gets the value of the equipmentstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getEQUIPMENTSTATUS() {
        return equipmentstatus;
    }

    /**
     * Sets the value of the equipmentstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setEQUIPMENTSTATUS(STATUS_Type value) {
        this.equipmentstatus = value;
    }

    /**
     * Gets the value of the lineardirectionid property.
     * 
     * @return
     *     possible object is
     *     {@link UCODEID_Type }
     *     
     */
    public UCODEID_Type getLINEARDIRECTIONID() {
        return lineardirectionid;
    }

    /**
     * Sets the value of the lineardirectionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link UCODEID_Type }
     *     
     */
    public void setLINEARDIRECTIONID(UCODEID_Type value) {
        this.lineardirectionid = value;
    }

}
